@@ -1,33 +1,35 @@
-{-# LANGUAGE PatternSynonyms #-}
-
 module Argo
     ( Value.Value
-        ( Pattern.Null
+        ( Pattern.Array
         , Pattern.Boolean
+        , Pattern.Null
         , Pattern.Number
-        , Pattern.String
-        , Pattern.Array
         , Pattern.Object
+        , Pattern.String
         )
     , Name.Name(Pattern.Name)
-    , Member.MemberOf(Member)
+    , Member.Member(Member)
     , Encode.encode
     , Encode.encodeWith
     , Indent.Indent(Spaces, Tab)
     , Decode.decode
-    , FromValue.FromValue(fromValue)
-    , ToValue.ToValue(toValue)
+    , FromValue.fromValue
+    , ToValue.toValue
+    , HasCodec.HasCodec(codec)
     , QuasiQuoter.value
     , QuasiQuoter.pointer
+    , QuasiQuoter.schema
     , Pointer.Pointer(Pointer)
     , Token.Token(Token)
     , Pointer.evaluate
     , Encode.encodePointer
     , Decode.decodePointer
     , Decimal.Decimal(Pattern.Decimal)
+    , Schema.Schema
     ) where
 
 import qualified Argo.Class.FromValue as FromValue
+import qualified Argo.Class.HasCodec as HasCodec
 import qualified Argo.Class.ToValue as ToValue
 import qualified Argo.Decode as Decode
 import qualified Argo.Encode as Encode
@@ -38,5 +40,6 @@ import qualified Argo.Pattern as Pattern
 import qualified Argo.Pointer.Pointer as Pointer
 import qualified Argo.Pointer.Token as Token
 import qualified Argo.QuasiQuoter as QuasiQuoter
+import qualified Argo.Schema.Schema as Schema
 import qualified Argo.Type.Decimal as Decimal
 import qualified Argo.Type.Indent as Indent
