@@ -13,17 +13,17 @@ import qualified Argo.Vendor.TemplateHaskell as TH
 import qualified Argo.Vendor.Transformers as Trans
 import qualified GHC.Generics as Generics
 
-newtype ArrayOf value
+newtype Array value
     = Array [value]
     deriving (Eq, Generics.Generic, TH.Lift, DeepSeq.NFData, Show)
 
-fromList :: [value] -> ArrayOf value
+fromList :: [value] -> Array value
 fromList = Array
 
-toList :: ArrayOf value -> [value]
+toList :: Array value -> [value]
 toList (Array x) = x
 
-encode :: (value -> Encoder.Encoder ()) -> ArrayOf value -> Encoder.Encoder ()
+encode :: (value -> Encoder.Encoder ()) -> Array value -> Encoder.Encoder ()
 encode f =
     Encoder.list
             (Trans.lift . Trans.tell $ Builder.word8 Literal.leftSquareBracket)
@@ -33,7 +33,7 @@ encode f =
             f
         . toList
 
-decode :: Decoder.Decoder value -> Decoder.Decoder (ArrayOf value)
+decode :: Decoder.Decoder value -> Decoder.Decoder (Array value)
 decode f = do
     Decoder.word8 Literal.leftSquareBracket
     Decoder.spaces
