@@ -2,6 +2,7 @@ module Argo.QuasiQuoter where
 
 import qualified Argo.Decode as Decode
 import qualified Argo.Json.Value as Value
+import qualified Argo.Schema.Schema as Schema
 import qualified Argo.Vendor.TemplateHaskell as TH
 import qualified Argo.Vendor.Text as Text
 
@@ -14,6 +15,15 @@ pointer = defaultQuasiQuoter
         . Text.pack
     }
 
+schema :: TH.QuasiQuoter
+schema = defaultQuasiQuoter
+    { TH.quoteExp =
+        either fail (TH.lift . Schema.fromValue)
+        . Decode.decode
+        . Text.encodeUtf8
+        . Text.pack
+    }
+
 value :: TH.QuasiQuoter
 value = defaultQuasiQuoter
     { TH.quoteExp =
